pub struct TemplateString(pub Vec<StringSegment>);Tuple Fields
0: Vec<StringSegment>Implementations
Sourceimpl TemplateString
impl TemplateString
Sourcepub fn rewrite_to_concatenated_strings(&self) -> Expr
pub fn rewrite_to_concatenated_strings(&self) -> Expr
Rewrites the ast for the template string to be a series of string concatenations
Sourcepub fn as_literal_string(&self) -> Option<&str>
pub fn as_literal_string(&self) -> Option<&str>
If the template string is just a single literal string return that string as we can just represent it in the ast as a single literal, otherwise return None as we will need to rewrite it into an expression.